package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````X"4```````!``````````%#!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````.`?````````X!\`````````
M$`````````$````%`````"``````````(``````````@````````Y44`````
M``#E10`````````0`````````0````0`````<`````````!P`````````'``
M``````"010```````)!%`````````!`````````!````!@```'B[````````
M>,L```````!XRP```````*@$````````"!4`````````$`````````(````&
M````B+L```````"(RP```````(C+````````,`(````````P`@````````@`
M````````!`````0````X`P```````#@#````````.`,```````!`````````
M`$``````````"``````````$````!````'@#````````>`,```````!X`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````0`````````!```````````@`````````4.5T9`0`
M``#`K0```````,"M````````P*T```````#L`````````.P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````>+L```````!XRP```````'C+````
M````B`0```````"(!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`(5]%SOS_.C<^')9Z[.58T)8>>C]!````!`````!````1TY5```````#
M````!```````````````O@```&$`````````````````````````````````
M```````````````````*`````````$``````````4@```!P`````````````
M`",`````````'0```!X`````````60``````````````````````````````
M6``````````5````````````````````.@`````````Y````````````````
M```````````````M`````````$<````L````!0```````````````````"<`
M````````3P```````````````````&``````````-P`````````F````0P``
M```````:````*P````````!6```````````````,```````````````-````
M`P```%$``````````````````````````````"\```!;`````````#\`````
M`````````````````````````!D`````````7`````L`````````````````
M````````$P```!\`````````/0````````!)````&P``````````````````
M`#L``````````````%\`````````)`````````!:`````````"D`````````
M``````D````S````````````````````,`````@``````````````!@```!4
M`````````"4```!"````!@``````````````,0``````````````!```````
M````````,@```"H````N````2P```%,````X````(@```$@````H````````
M``````````````````````````````````````!!````10```"`````V````
M````````````````3@```````````````````$H```````````````````!5
M`````````%T```!,```````````````\````/@``````````````1````$8`
M```U````#P```"$`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````!<`````
M``````````````````````````(`````````%``````````1````$```````
M```'`````````````````````````````````````````%`````2````````
M```````````````````````````````````````!````````````````````
M````````````````#@```$T`````````````````````````````````````
M`````````````````````````%<`````````````````````````-```````
M`````````````%X````6````````````````````````````````````````
M```````K````1P````0````(````(!`0``5`!(0H`@`$@(8`A(()```)(`0(
MB(`10;H``@A'````2`````````!)``````````````!*``````````````!+
M`````````$P`````````3@``````````````3P```%``````````40```%(`
M``!4`````````%4```!6````5P``````````````````````````````6```
M`%D```!:````6P```%P``````````````%X`````````7P``````````````
MB0=PT]%ESFUK&IY0H^#[2>-'Q@%FK\QF0T75[+OCDGRS`8MO;\7?'Q6,)<PN
MQ9NV:PE#UB'_Y`[[H6Q@P^4_+`TZEPO/WD<MV7%8''^IG)OAIP(*0OK7AVM_
MFGPS8MOMU&34?*U+X\``````````````````````````````````````*`(`
M`!(`````````````````````````S`(``!(`````````````````````````
MA@$``!(`````````````````````````E@(``!(`````````````````````
M````C````!$`````````````````````````#P(``!(`````````````````
M````````+P$``!(`````````````````````````=`(``!(`````````````
M````````````L0$``!(``````````````````````````0```"``````````
M````````````````20(``!(`````````````````````````9P```!(`````
M````````````````````D0(``!(`````````````````````````E````!(`
M````````````````````````"`(``!(`````````````````````````0`(`
M`!(`````````````````````````V`(``!(`````````````````````````
MG`(``!(`````````````````````````PP```!(`````````````````````
M````TP```!(`````````````````````````(0$``!(`````````````````
M````````50$``!(`````````````````````````B@```!$`````````````
M````````````P`,``!(`````````````````````````$````"``````````
M````````````````X@$``!(`````````````````````````+0(``!(`````
M````````````````````K@```!(`````````````````````````+````"``
M````````````````````````3P(``!(`````````````````````````G```
M`!(`````````````````````````,@(``!(`````````````````````````
MV0```!8`````````````````````````[````!(`````````````````````
M````Q`$``!(`````````````````````````!P,``!(`````````````````
M````````!P$``!(`````````````````````````[0$``!(`````````````
M````````````@@(``!(`````````````````````````FP$``!(`````````
M````````````````-@$``!(`````````````````````````&`$``!(`````
M````````````````````O@(``!(`````````````````````````10$``!(`
M````````````````````````8P$``!(`````````````````````````&@(`
M`!(`````````````````````````7`(``!(`````````````````````````
M?P$``!(`````````````````````````Y@(``!(`````````````````````
M````>0```!(`````````````````````````<0$``!(`````````````````
M````````:@$``!(`````````````````````````3@(``!(`````````````
M````````````E`$``!(`````````````````````````\@(``!(`````````
M````````````````_`$``!(`````````````````````````B0(``!(`````
M````````````````````R@```!(`````````````````````````M0```!(`
M````````````````````````;0(``!$`````````````````````````U0$`
M`!$`````````````````````````>`$``!(`````````````````````````
M30$``!(`````````````````````````_````!(`````````````````````
M````H@$``!(`````````````````````````1@```!(`````````````````
M````````7`$``!(`````````````````````````I````!(`````````````
M````````````5@(``!(`````````````````````````K`(``!(`````````
M````````````````400``!$`&0`8T`````````@`````````6````"(`````
M````````````````````I`,``!(`$``P5````````"L"````````6P0``!(`
M$``P2P```````),#````````40,``!(`$``@2@```````"4`````````F`,`
M`!(`$`!02@```````-0`````````*P0``!``&0`@T```````````````````
M&00``!``&@"`X```````````````````=`,``!(`$`#03@```````,0`````
M````R0,``!(`$`!`40```````&X!````````$`0``!(`$`#P4````````$4`
M````````0`,``!(`$`"P1P````````4`````````Y`,``!``&0``T```````
M````````````1`0``!(`$`#`1P```````%8"````````,@0``!(`$`#`3P``
M`````"X!````````_`,``!(`$`"P1@```````#4`````````Y@,``"``&0``
MT```````````````````'@0``!(`$`!@5@```````)P*````````!`0``!``
M&@`@T```````````````````K@,``!(`$`"@3P```````!T`````````@@,`
M`!(`$`#P1@```````+D`````````\0,``!(`$`"P4@```````'\!````````
M4P```!(`$`#@(P```````/P!````````Z@,``!(`$`#@)0```````"(`````
M````7@,``!(`$```80```````,H$````````U0,``!$`$@``<`````````0`
M`````````%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M
M86EN`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?
M8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``;W!E;F1I<@!R96%D9&ER-C0`
M<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M9&ER`%!,
M7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!0
M97)L7VYE=UA37V9L86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR
M`%!E<FQ?<W9?<V5T<'9N`&UE;6UO=F4`<F5A;&QO8P!G971P:60`;65M8W!Y
M`'-T<F-H<@!S=')T;VL`<W1R8VUP`&%C8V5S<P!S=')D=7``7U]S=')N8W!Y
M7V-H:P!G971U:60`<W1R<W1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K
M7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O7W5N9'5M<`!P97)L7V%L
M;&]C`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A
M<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R
M;%]R=6X`97AI=`!L<W1A=#8T`&UK9&ER`%]?97)R;F]?;&]C871I;VX`<W1D
M97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`<F5A9`!C;&]S90!0
M97)L7V=V7V9E=&-H<'8`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]A=E]F971C
M:`!097)L7V=E=%]S=@!097)L7V%V7W-H:69T`%!E<FQ?;6=?<V5T`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%]?=&QS7V=E=%]A9&1R`&QI8G!E<FPN<V\`;&EB
M8RYS;RXV`&QD+6QI;G5X+7@X-BTV-"YS;RXR`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L
M96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN
M86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/
M7W-T9&EN7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI=`!?
M7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?
M:6YI=%]E;G8`1TQ)0D-?,BXS`$=,24)#7S(N,30`1TQ)0D-?,BXS-`!'3$E"
M0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C(N-0!'3$E"
M0U\R+C,N-``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210`````!``$`
M`@`#``,``0`#``(``0`!``,`!``#``,``P`!``$``0`#``,``0`#``,``P`!
M``$``P`#``$`!0`#``$``0`!``$`!@`!``$``P`#``$``P`!``,``P`!``,`
M`P`!``<``P`#``4``P`!``$``P`#``(``P`!``,``P`!``$`"``)``,``P`!
M``$``P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`````````!``$`*P,``!`````@````$VEI#0``!@!H!```````
M``$`!P`A`P``$`````````"4D98&```)`'($```0````M)&6!@``"`!]!```
M$````!1I:0T```<`B`0``!````"SD98&```%`)($```0````<AEI"0``!`"=
M!```$````'4::0D```,`J00``!````!T&6D)```"`+4$````````>,L`````
M```(`````````,`F````````@,L````````(`````````(`F````````"-``
M```````(``````````C0````````&-`````````(`````````.!R````````
MH,\````````&````!0``````````````J,\````````&````"0``````````
M````L,\````````&````"@``````````````N,\````````&````&0``````
M````````P,\````````&````'0``````````````R,\````````&````2```
M````````````T,\````````2````(0``````````````V,\````````&````
M(@``````````````X,\````````&````(P``````````````Z,\````````&
M````/```````````````\,\````````&````/0``````````````^,\`````
M```&````0@``````````````T,T````````'`````0``````````````V,T`
M```````'`````@``````````````X,T````````'`````P``````````````
MZ,T````````'````!```````````````\,T````````'````!@``````````
M````^,T````````'````!P```````````````,X````````'````"```````
M````````",X````````'````"P``````````````$,X````````'````#```
M````````````&,X````````'````#0``````````````(,X````````'````
M#@``````````````*,X````````'````#P``````````````,,X````````'
M````$```````````````.,X````````'````$0``````````````0,X`````
M```'````$@``````````````2,X````````'````$P``````````````4,X`
M```````'````%```````````````6,X````````'````%0``````````````
M8,X````````'````%@``````````````:,X````````'````&```````````
M````<,X````````'````&@``````````````>,X````````'````&P``````
M````````@,X````````'````'```````````````B,X````````'````'@``
M````````````D,X````````'````'P``````````````F,X````````'````
M(```````````````H,X````````'````)```````````````J,X````````'
M````)0``````````````L,X````````'````)@``````````````N,X`````
M```'````)P``````````````P,X````````'````*```````````````R,X`
M```````'````*0``````````````T,X````````'````*@``````````````
MV,X````````'````*P``````````````X,X````````'````+```````````
M````Z,X````````'````+0``````````````\,X````````'````+@``````
M````````^,X````````'````+P```````````````,\````````'````,```
M````````````",\````````'````,0``````````````$,\````````'````
M,@``````````````&,\````````'````,P``````````````(,\````````'
M````-```````````````*,\````````'````-0``````````````,,\`````
M```'````-@``````````````.,\````````'````-P``````````````0,\`
M```````'````.```````````````2,\````````'````.0``````````````
M4,\````````'````.@``````````````6,\````````'````.P``````````
M````8,\````````'````/@``````````````:,\````````'````/P``````
M````````<,\````````'````0```````````````>,\````````'````00``
M````````````@,\````````'````0P``````````````B,\````````'````
M1```````````````D,\````````'````10``````````````F,\````````'
M````1@``````````````````````````````````````````````````````
M``!(@^P(2(L%I:\``$B%P'0"_]!(@\0(PP```````````/\UFJT``/\EG*T`
M``\?0`#_)9JM``!H`````.G@_____R62K0``:`$```#IT/____\EBJT``&@"
M````Z<#_____)8*M``!H`P```.FP_____R5ZK0``:`0```#IH/____\E<JT`
M`&@%````Z9#_____)6JM``!H!@```.F`_____R5BK0``:`<```#I</____\E
M6JT``&@(````Z6#_____)5*M``!H"0```.E0_____R5*K0``:`H```#I0/__
M__\E0JT``&@+````Z3#_____)3JM``!H#````.D@_____R4RK0``:`T```#I
M$/____\E*JT``&@.````Z0#_____)2*M``!H#P```.GP_O___R4:K0``:!``
M``#IX/[___\E$JT``&@1````Z=#^____)0JM``!H$@```.G`_O___R4"K0``
M:!,```#IL/[___\E^JP``&@4````Z:#^____)?*L``!H%0```.F0_O___R7J
MK```:!8```#I@/[___\EXJP``&@7````Z7#^____)=JL``!H&````.E@_O__
M_R72K```:!D```#I4/[___\ERJP``&@:````Z4#^____)<*L``!H&P```.DP
M_O___R6ZK```:!P```#I(/[___\ELJP``&@=````Z1#^____):JL``!H'@``
M`.D`_O___R6BK```:!\```#I\/W___\EFJP``&@@````Z>#]____)9*L``!H
M(0```.G0_?___R6*K```:"(```#IP/W___\E@JP``&@C````Z;#]____)7JL
M``!H)````.F@_?___R5RK```:"4```#ID/W___\E:JP``&@F````Z8#]____
M)6*L``!H)P```.EP_?___R5:K```:"@```#I8/W___\E4JP``&@I````Z5#]
M____)4JL``!H*@```.E`_?___R5"K```:"L```#I,/W___\E.JP``&@L````
MZ2#]____)3*L``!H+0```.D0_?___R4JK```:"X```#I`/W___\E(JP``&@O
M````Z?#\____)1JL``!H,````.G@_/___R42K```:#$```#IT/S___\E"JP`
M`&@R````Z<#\____)0*L``!H,P```.FP_/___R7ZJP``:#0```#IH/S___\E
M\JL``&@U````Z9#\____)>JK``!H-@```.F`_/___R7BJP``:#<```#I</S_
M__\EVJL``&@X````Z6#\____)=*K``!H.0```.E0_/___R7RJP``9I``````
M`````%532(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H
M````2(E$)"@QP.AH____2(LUB:L``$B+/;JK``!(B?+HHD$``$B+!;NK``"`
M.`!U-^@Q_?__2(G'2(D%_ZL``$B%P`^$@`$``.B9_?__9$B+!"4`````2`,%
M::L``$B+`,:`UPD```!D2(L$)0````!(`P5/JP``2(L`@(@J!````XM$)!R-
M>`5(8_](P><#Z'+^__],BT0D$+X!````QP6FJP``!````$B)P4B)!:2K``!$
MBTPD'$F+`$R)RDB)`4B-!6U,``!(B4$(2(T%/*L``$B+`$B)01!(C0573```
M2(E!&$&#^0%^&P\?0`!)BP3PC7X#2(/&`4AC_TB)!/E,.<YUZ4B+/3*K``"#
MP@-%,<!(C36M'0``2&/"2,<$P0````#H/?O__XG#A<!T44B+/0BK``!(C6PD
M).@F_?__,<!(B>Y(C3V12P``Z$4:``!(A<!T.DB+/>&J``#HQ/K__^A/_/__
M2(M$)"AD2"L$)2@```!U3$B#Q#B)V%M=PTB+/;>J``#H6OO__XG#ZY](BSVO
MJ@``2(7_=`?HE2L``.NS2(T]HDH``$B)[NCD&0``2(G'2(D%BJH``$B%P'25
MZ]GHWOS__[\!````Z,3Z__\/'T``,>U)B=%>2(GB2(/D\%!413'`,<E(C3WE
M_?___Q7WJ0``]&8N#Q^$```````/'T``2(T]":H``$B-!0*J``!(.?AT%4B+
M!8ZI``!(A<!T"?_@#Q^``````,,/'X``````2(T]V:D``$B--=*I``!(*?Y(
MB?!(P>X_2,'X`T@!QDC1_G042(L%5:D``$B%P'0(_^!F#Q]$``###Q^`````
M`/,/'OJ`/96I````=2M(@STSJ0```%5(B>5T#$B+/6:I``#H*?W__^AD____
M7<8%;*D```'##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=(B?I!5D%5
M05154TB![)@"``!(BW<X9$B+!"4H````2(F$)(@"``"+1SA(B?%(P>D@#\B)
MP$B)!"1(B?!(P>XX2,'H*"4`_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)
M\$B+=T!("<A(B40D"(M'0$B)\4C!Z2`/R(G`2(E$)!!(B?!(P>XX2,'H*"4`
M_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)\$B+=TA("<A(B40D&(M'2$B)
M\4C!Z2`/R(G`2(E$)"!(B?!(P>XX2,'H*"4`_P``2`GP2(G.2,'A"$C!YAB!
MX0``_P")]D@)\$B+=U!("<A(B40D*(M'4$B)\4C!Z2`/R(G`2(E$)#!(B?!(
MP>XX2,'H*"4`_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)\$B+=UA("<A(
MB40D.(M'6$B)\4C!Z2`/R(G`2(E$)$!(B?!(P>XX2,'H*"4`_P``2`GP2(G.
M2,'A"$C!YAB!X0``_P")]D@)\$B+=V!("<A(B40D2(M'8$B)\4C!Z2`/R(G`
M2(E$)%!(B?!(P>XX2,'H*"4`_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)
M\$@)R$B)1"18BT=H2(MW:&8/;V0D$&8/;UPD(`_(B<!F#V],)#!(B40D8$B)
M\$B)\68/;Q6,A```2,'H*$C!Z2`E`/\``$C![CA("?!(B<Y(P>$(2,'F&('A
M``#_`(GV2`GP2(MW<$@)R$B)1"1HBT=P2(GQ2,'I(`_(B<!(B40D<$B)\$C!
M[CA(P>@H)0#_``!("?!(B<Y(P>$(2,'F&('A``#_`(GV2`GP2`G(2(E$)'A(
MC8PD:`(``$B-1"1H#Q]$``!F#V]HV&8/[V"89@_O6*AF#^](N/,/;P!(@\!`
M9@_OQ68/[\1F#V_@9@]ST!]F#W/T`68/Z\1F#V]@J&8/V\(/*4#8\P]O0-!F
M#^_$9@_OPV8/;]AF#W/0'V8/<_,!9@_KPV8/;UBX9@_;P@\I0.CS#V]`X&8/
M[\-F#^_!9@]OR&8/<]`?9@]S\0%F#^O!9@_;P@\I0/CS#V]`\&8/;TC(9@_O
MQ68/;VB(9@_OZ68/[\5F#V_H9@]S\`%F#W/5'V8/Z\5F#]O"#RE`"$@YR`^%
M+/___TR+"DR+6A!(BWH@2(M:&$R)R$R)R4B+:@A(P>D;2,'@!4B+="0(2`G(
M`P0D2(VT,YEY@EJ-C#B9>8):3(G82#'82"'H2#'8C3P!2(GI2(GH2,'H`DC!
MX1Y)B?I("<%,B=A)P>H;08G(3#'`3"'(3#'82`'P2(G^2,'F!4P)UDR+5"00
M1(TD,$R)R$R)SDC![@)(P>`>38GE2`GP2<'M&T^-E!.9>8):2#'!B<9((?E,
M,<%,`=%-B>))P>(%30GJ3(ML)!A!`<I(B?E(P>\"2,'A'D6)TD@)^4^-A"B9
M>8):2#'(38G53"'@2<'M&XG/2#'P3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@
M2<'L`DC!X!Y%B<!,">!*C;0NF7F"6D@QP4V)Q4PAT4G![1M!B<1(,?E(`?%,
MB<9(P>8%3`GN3(ML)"@!SDR)T4G!Z@)(P>$>B?9,"=%*C;POF7F"6D@QR$F)
M]4PAP$G![1M!B<I,,>!(`?A(B?=(P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>
MB?],"<!/C:0LF7F"6D@QP4F)_4@A\4G![1M!B<!,,=%,`>%)B?Q)P>0%30GL
M3(ML)#A!`<Q(B?%(P>X"2,'A'D6)Y$@)\4^-E"J9>8):2#'(38GE2"'X2<'M
M&XG.3#'`3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)("?A/
MC80HF7F"6D@QP4V)U4PAX4G![1N)QT@Q\4P!P4V)T$G!X`5-">A,BVPD2$$!
MR$R)X4G![`)(P>$>18G`3`GA2HVT+IEY@EI(,<A-B<5,(=!)P>T;08G,2#'X
M2`'P3(G&2,'F!4P)[DR+;"10`<9,B=!)P>H"2,'@'HGV3`G02HV\+YEY@EI(
M,<%)B?5,(<%)P>T;08G"3#'A2`'Y2(GW2,'G!4P)[TR+;"18`<],B<%)P>@"
M2,'A'HG_3`G!3XVD+)EY@EI(,<A)B?U((?!)P>T;08G(3#'03`'@28G\2<'D
M!4T)[$R+;"1@00'$2(GP2,'@'DC![@)%B>1("?!/C90JF7F"6D@QP4V)Y4@A
M^4G![1N)QDPQP4P!T4V)XDG!X@5-">I,BVPD:$$!RDB)^4C![P)(P>$>18G2
M2`GY3XV$*)EY@EI(,<A-B=5,(>!)P>T;B<](,?!,`<!-B=!)P>`%30GH3(ML
M)'!!`<!,B>!)P>P"2,'@'D6)P$P)X$J-M"Z9>8):2#'!38G%3"'12<'M&T&)
MQ$@Q^4@!\4R)QDC!Y@5,">Y,BVPD>`'.3(G12,'A'DG!Z@*)]DP)T4J-O"^9
M>8):2#'(28GU3"'`2<'M&T&)RDPQX$@!^$B)]TC!YP5,">],BZPD@`````''
M3(G`2<'H`DC!X!Z)_TP)P$^-I"R9>8):2#'!28G]2"'Q2<'M&T&)P$PQT4P!
MX4F)_$G!Y`5-">Q&C2PA2(GQ3(ND)(@```!(P>X"2,'A'D@)\4@QR(G.3XV4
M(IEY@EI((?A-B>Q,,<!)P>P;3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX
M2,'@'DC![P)%B=)("?A/C80@F7F"6D@QP4V)U$PAZ4G![!N)QT@Q\4P!P4V)
MT$G!X`5-">!%B<!,`<%-B>A)P>T"2<'@'D&)S$T)Z$R+K"28````3#'`3"'0
M2#'X2HVT+IEY@EI-B>5(`?!,B>9)P>T;2,'F!4P)[HGV2`'P3(G62<'J`DC!
MYAY!B<5,"=9-B<)%B<!),?)$,=%,BY0DH````$J-O!>AZ]EN38GJ2`'/3(GI
M2<'J&TC!X05,"=&)R4@!STR)X4C!X1Y,`X0DJ````$G![`)!B?I,">%)B?1)
M,<R)]D@#M"2P````1#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$
M3(GH2<'M`DC!X!Y%B>!,">A)B<V)R4@#C"2X````23'%1#'O3(VL/J'KV6Y,
MB<9,B<=(P>\;2,'F!4@)_HGV20'U3(G62<'J`DC!YAY$B>],"=9)B<*)P$DQ
M\D4QXDZ-I!&AZ]EN2(GY28GZ2<'J&TC!X05,"=&)R4D!S$R)P4G!Z`)(P>$>
M18GB3`G!2`.$),````!)B?")]DDQR$@#M"3(````13'H3HVL`*'KV6Y,B=!-
MB=!)P>@;2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B<^)R4@#C"30
M````2#''1#'G3(VD/J'KV6Y,B<9,B<=(P>\;2,'F!4@)_HGV20'T3(G62<'J
M`DC!YAY$B>=,"=9)B<*)P$@#A"38````23'R13'J3HVL$:'KV6Y(B?E)B?I)
MP>H;2,'A!4P)T8G)20'-3(G!2<'H`DC!X1Y%B>I,"<%)B?")]DDQR$@#M"3@
M````13'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!
MX!Y%B>!("?A(B<^)R4@#C"3H````2#''1#'O3(VL/J'KV6Y,B<9,B<=(P>\;
M2,'F!4@)_HGV20'U3(G62<'J`DC!YAY$B>],"=9)B<*)P$@#A"3P````23'R
M13'B3HVD$:'KV6Y(B?E)B?I)P>H;2,'A!4P)T8G)20',3(G!2<'H`DC!X1Y%
MB>),"<%)B?")]DDQR$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`[0D^```
M`$P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B<^)R4@#C"0``0``2#''1#'G
M3(VD/J'KV6Y,B<9,B<=(P>\;2,'F!4@)_HGV20'T3(G62<'J`DC!YAY$B>=,
M"=9)B<*)P$@#A"0(`0``23'R13'J3HVL$:'KV6Y(B?E)B?I)P>H;2,'A!4P)
MT8G)20'-3(G!2<'H`DC!X1Y%B>I,"<%)B?")]DDQR$4QX$Z-I`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<!(`[0D$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(
MB<^)R4@#C"08`0``2#''1#'O3(VL/J'KV6Y,B<9,B<=(P>\;2,'F!4@)_HGV
M20'U3(G62<'J`DC!YAY$B>],"=9)B<*)P$@#A"0@`0``23'R13'B3HVD$:'K
MV6Y(B?E)B?I)P>H;2,'A!4P)T8G)20',3(G!2<'H`DC!X1Y%B>),"<%)B?")
M]DDQR$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(
M`[0D*`$``$C![P)%B>A("?A(B<](,<>)R4@#C"0P`0``1#'G38G$2(VT/J'K
MV6Y,B<=)P>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?Y-,>*)]XG`
M2`.$)#@!``!%,>I)B?U.C901H>O9;DB)^4G![1M(P>$%3`GI00'*3(G!2<'H
M`DC!X1Y%B=),"<%-B>!%B>1),<A)B<Y!B<U$,<9-B=!(C;0PH>O9;DR)T$G!
MZ!M(P>`%3`G`1(T$!DB)_DC![P)(P>8>N-R\&X]("?Y)"?:)]T@A^4TAUDD)
MSDB+C"1``0``2`'!3`'A38G$3`'Q38G&2<'D!4G![AM-"?1!`<Q,B=%)P>H"
M2,'A'D6)Y$P)T4@)SDF)SD&)RDDA_DPAQDP)]DR+M"1(`0``20'&30'U38GF
M3`'N38GE2<'N&TG!Y05-"?5)B<Y!`?5,B<9)P>@"2,'F'D6)[4P)QD&)\$D)
M]DTAYDPAP4P)\4R+M"10`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?<!
MSTR)X4G![`)(P>$>B?],">%("<Y)B<Y!B<Q-(<9,(>Y,"?9,B[0D6`$``$D!
MQDT!\DF)_DP!UDF)^DG![AM)P>(%30GR28G.00'R3(GN2<'M`DC!YAY%B=),
M">Y!B?5)"?9)(?Y,(>E,"?%,B[0D8`$``$D!QDT!\$V)UDP!P4V)T$G!X`5)
MP>X;30GP00'(2(GY2,'O`DC!X1Y%B<!("?E("<Y)B<Z)STTA[DPAUDP)]DR+
MM"1H`0``20'&30'T38G&3`'F38G$2<'N&TG!Y`5-"?1)B<Y!`?1,B=9)P>H"
M2,'F'D6)Y$P)UD&)\DD)]DTAQDPAT4P)\4R+M"1P`0``20'&30'U38GF3`'I
M38GE2<'N&TG!Y05-"?5!`<U,B<%(P>$>2<'H`D6)[4P)P4@)SDF)SD&)R$TA
MUDPAYDP)]DR+M"1X`0``20'&3`'W38GN2`'^3(GO2<'N&TC!YP5,"?=)B<X!
M]TR)YDG![`)(P>8>B?],">9!B?1)"?9-(>Y,(>%,"?%,B[0D@`$``$D!QDT!
M\DF)_DP!T4F)^DG![AM)P>(%30GR00'*3(GI2<'M`DC!X1Y%B=),">E("<Y)
MB<Y!B<U((?Y-(>9,"?9,B[0DB`$``$D!QDT!\$V)UDP!QDV)T$G![AM)P>`%
M30GP28G.00'P2(G^2,'O`DC!YAY%B<!("?Z)]TD)]DTAUD@A^4P)\4R+M"20
M`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1!`<Q,B=%)P>H"2,'A'D6)
MY$P)T4@)SDF)SD&)RDDA_DPAQDP)]DR+M"28`0``20'&30'U38GF3`'N38GE
M2<'N&TG!Y05-"?5)B<Y!`?5,B<9)P>@"2,'F'D6)[4P)QD&)\$D)]DTAYDPA
MP4P)\4R+M"2@`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?<!STR)X4G!
M[`)(P>$>B?],">%("<Y)B<Y!B<Q-(<9,(>Y,"?9,B[0DJ`$``$D!QDT!\DF)
M_DP!UDF)^DG![AM)P>(%30GR28G.00'R3(GN2<'M`DC!YAY%B=),">Y!B?5)
M"?9)(?Y,(>E,"?%,B[0DL`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP
M00'(2(GY2,'O`DC!X1Y%B<!("?E("<Y)B<Z)STTA[DPAUDP)]DR+M"2X`0``
M20'&30'T38G&3`'F38G$2<'N&TG!Y`5-"?1)B<Y!`?1,B=9)P>H"2,'F'D6)
MY$P)UDD)]D&)\DTAQDPAT4P)\4R+M"3``0``20'&30'U38GF3`'I38GE2<'N
M&TG!Y05-"?5!`<U,B<%)P>@"2,'A'D6)[4P)P4@)SDF)R$&)STTAT$PAYDP)
MQDR+A"3(`0``20'`3`''38GH2`'^3(GO2<'H&TC!YP5,"<=$C00^3(GG2<'L
M`DC!YQY(B<Y,">=!B?Q("?Y,(>Y,(>%("?%(B[0DT`$``$@!QDP!UDV)PD@#
MA"38`0``2`'Q3(G&2<'J&TC!Y@5,"=:)]D@!\4R)[DG![0)(P>8>08G*3`GN
M2`GW28GU08GV3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G!
M[1M,">B)P$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<8QSDB+C"3@`0``
M2`'!3`'A38GL2`'Q3(GN2<'L&TC!Y@5,">9-B=2)]DG!Y!Y(`?%)P>H"20''
M30GB38G$B<Y-,=1%B<!$,>=,BZ0DZ`$``$D!Q$T!]$F)]DP!YTF)]$G![AM)
MP>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)
MUDTQ[D0Q\4V)YDD!R$R)X4G![AM(P>$%3`GQB<E)`<A(B?%(P>X"2,'A'D6)
MQD@)\42)UDV)ZDDQRDP!_DR+O"0``@``1#'738GR2`'W3(GV2,'F!4G!ZAM,
M"=9)`<>)]D@!]TR)YDG![`)(P>8>08GZ20GT1(GN28G-33'E3`'^B<E,B[PD
M$`(``$4QZ$V)U4D!\$R)UDG![1M(P>8%3`GN20''B?9)`?!,B?9)P>X"2,'F
M'D6)Q4P)]DR+M"0(`@``20'&3`'Q38GF23'V1#'W38GN2`'/3(GI2<'N&TC!
MX05,"?&)R4@!STR)T4G!Z@)(P>$>08G^20G*1(GA28GT3`'Y33'4B?9,B[PD
M(`(``$4QX$V)]$D!R$R)\4G![!M(P>$%3`GA20''B<E)`<A,B>E)P>T"2,'A
M'D6)Q$P)Z4R+K"08`@``20'%3`'N38G523'-1#'O38GE2`'W3(GF2<'M&TC!
MY@5,">Z)]D@!]TR)]DG![@)(P>8>08G]20GV1(G628G*33'R3`'^B<E,B[PD
M,`(``$4QT$V)ZDD!\$R)[DG!ZAM(P>8%3`G6B?9)`?!,B>9(P>8>2<'L`D6)
MPDP)YDR+I"0H`@``20''20'$3`'A38GT23'T1#'G38G42`'/3(G12<'L&TC!
MX05,">&)R4@!STR)Z4G![0)(P>$>08G\20G-1(GQ28GV33'N3`'YB?9,B[PD
M0`(``$4Q\$V)YDD!R$R)X4G![AM(P>$%3`GQB<E)`<A,B=%)P>H"2,'A'D6)
MQDP)T4R+E"0X`@``20'"3`'638GJ23'*1#'738GR2`'W3(GV2,'F!4G!ZAM)
M`<=,"=:)]D@!]TR)YDG![`)(P>8>08GZ20GT1(GN28G-33'E3`'^B<E,B[PD
M8`(``$4QZ$V)U4D!\$R)UDG![1M(P>8%3`GNB?9)`?!,B?9)P>X"2,'F'D6)
MQ4P)]DR+M"1(`@``20'&3`'Q38GF18GD23'V1#'W38GN2`'/3(GI2<'N&TC!
MX05,"?&)R4@!STR)T4G!Z@)(P>$>08G^20G*2(N,)%`"``!(`<%)`<Q(B?&)
M]DPQT4D!QT0QP4V)\$D!S$R)\4G!Z!M(P>$%3`G!B<E)`<Q,B>E)P>T"2,'A
M'D6)X$P)Z4R+K"18`@``20'%3`'N38G523'-1#'O38G%2`'W3(G&2<'M&TC!
MY@5,">Z)]D@!]TR)]DG![@)(P>8>08G]20GV1(G628G*33'R3`'^B<E,B[PD
M<`(``$4QXDV)[$P!UDV)ZDG![!M)P>(%30GB38G$18G22<'D'DP!UDG!Z`))
M`<=-">!,BZ0D:`(``$&)\DD!Q$@#A"1X`@``3`'A38GT33'$1#'G38G42`'/
M3(G12<'L&TC!X05,`<A,">%-B>Q)P>T"2<'D'HG)30GE18GT38G&33'N2`'/
M30'\B?E$,?9%B<!,`>9)B<Y)B<Q)P>0%2<'N&TP!P$T)]$V)Z$0!YDV)U$G!
MZ@))P>0>B?9-">)-,=!$,<=)B?!(`?A(B?=(P><%2<'H&T0#:B`![DP)QT$!
MVDB)<@@!^$R)4AA(B0)(B<A(P>D"2,'@'DR):B!("<A$`=A(B4(02(N$)(@"
M``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^@7X___#Q^``````$%7
M059!54%455-(@^P(2(7_#X2Q````2(L%XH\``$R+,$V%]@^$G@````^V!TF)
M_TF)]83`=`0\/75513'D28L>2(7;=#!-8^1,B?4/'T``3(GB3(G^2(G?Z-+@
M__^%P'4'0H`\(SUT1TB+70A(@\4(2(7;==I(@\0(2(G86UU!7$%=05Y!7\,/
M'X0``````$F)_$$/MD0D`4F#Q`&$P'0$/#UU[D4I_.N49@\?1```2HU<(P%,
M*?5(P?T#08EM`.NT9@\?1```,=OKJ@\?0`!!5T%6055!5%5(B?U32(/L"$R+
M)1B/``!-BS0D387V=&8/MD4`/#T/A+@````/'P"$P`^$K0```$F)[T$/MD<!
M28/'`83`=`0\/77O02GO38LN387M=#!-8_],B?,/'P!,B?I(B>Y,B>_H\M__
M_X7`=0A#@'P]`#UT)DR+:PA(@\,(387M==E(@\0(6UU!7$%=05Y!7\-F+@\?
MA```````28L$)$PI\TC!^P-(8]M(C0382(M0"$B)$$B%TG029I!(BU`02(/`
M"$B)$$B%TG7P38LT)$V%]G2N#[9%`#P]#X5+____13'_Z6+___\/'P!!54%4
M55-(@>RH````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G[=2M(BX0D
MF````&1(*P0E*`````^%(P$``$B!Q*@```!;74%<05W#9@\?1```Z//?__](
MB<5(A<!TR$B)[^C3X?__2(7`#X2R````@'@3+DR-8!-U$$&`?"0!`'3=#Q^$
M``````"`>!,N#X2F````2(G?Z([?__],B>=)B<7H@]___T&-?`4"2&/_Z,;>
M__]-B>%)B=B^`0```$F)Q4B)QS'`2(T-T"T``$C'PO_____H`.'__TR)[TB)
MYNA5W___3(GO@_C_=!"+1"08)0#P```]`$```'1=Z+C>__],B>_H$-___TB)
M[^@HX?__2(7`#X55____#Q^``````$B)[^B@X/__2(G?Z)C>___I\/[__P\?
M`$&`?"0!+@^%3O___T&`?"0"``^$#?___^D]____#Q\`Z)O^___KH>CDW___
M#Q]``%-D2(L$)0````!(`P7OC```2(L5\(P``$B-#5EJ``!(C344+0``2(LX
M2(G#Z&_@__](BSM,C06K+@``13')6TR)P4B-%><=``!(C34&+0``Z;O>__]F
M9BX/'X0``````$%5NO\/``!!5%5(B?532(G[2(T]\RP``$B![!@0``!D2(L$
M)2@```!(B80D"!```#'`28GD3(GFZ,/>__^%P'X2B<&#Z`%(8]"`/!0`=5&%
MP'5%9$B+!"4`````2`,%/8P``$B)ZDB)WDB+..B?W?__2(N$)`@0``!D2"L$
M)2@```!U5TB!Q!@0``!;74%<05W#9@\?1```B<%F#Q]$``!,8^F^+P```$R)
MYTR)ZNB=W/__2(7`=)MD2(L$)0````!(`P78BP``3(GI3(GB2(G>2(LXZ!?>
M___KENB@WO__05=!5D%5051)B?152(G]4TB#[!B`/CUU!$F#Q`%,B>?H6]W_
M_TB)1"0(2(L%7XL``$B+`$R+,$B)!"0/MD4`A,!!#Y7%/#T/E<`QVT$@Q0^%
MZP$``$V%]@^$,P(``$R+/"1(8]L/'P!(B=I(B>Y,B??H2MS__X7`=0M!@#P>
M/0^$LP```$V+=PA)@\<(387V==9(BP0D13'M#Q^``````$B#P`A$B>I!@\4!
M2(,X`'7OC7(#2&/V2,'F`XL%;XL``(7`#X67`0``QP5=BP```0```$B)]^CU
MV___2(7`#X0=`0``2(LT)$ECW4B)QTC!XP-(B=KH1MW__TB)P4B+!8R*``!(
MB0A(B<9!@\4!36/M2L<$Z0`````/MD4`2(LVA,!!#Y7%/#U(B30D#Y7`02'%
MZS0/'T``28U<'@%(B=_H.]S__TB+?"0(2#GX#X.]````2(L$)$V)^$DIP$G!
M^`-)8]A(P>,#183M#X09`0``2(GH#Q]```^V4`%(@\`!A-)T!8#Z/77O2"GH
M2)A(BW0D"$B-?`8"Z#/;__](BS0D2(D$'DB%P'172(L%WXD``$B-30%(BP!(
MBQ08#[9%`(@"/#UU&^L=#Q^$```````/M@%(@\(!2(/!`8@"/#UT!(3`=>O&
M`CTQP&8/'T0``$$/M@P$B$P"`4B#P`&$R77O2(/$&%M=05Q!74%>05_#,<!F
M#Q]$``!!#[84!(@4`TB#P`&$TG7P2(/$&%M=05Q!74%>05_#9@\?A```````
M2(GK#[9#`4B#PP&$P'0$/#UU\"GKZ?O]__]F#Q]$``!(BSPDZ.?<__](B<%(
MBP4=B0``2(D(2(7)=(9)8]U(B<9(P>,#Z8#^__\QP.G]_O__OA````!%,>WI
M'?[__V:02(/L"&1(BP0E`````$@#!0R)``!(BQ4-B0``2(T-=F8``$B--3$I
M``!(BSA(@\0(Z8O<__]F9BX/'X0``````%532('L*"```&1(BP0E*````$B)
MA"08(```,<!(C9PD$!```$B)Y>@TVO__N@$0``!(B=^^`0```$R-#18I``!!
MB<`QP$B-#0XI``#H_]O__[H`$```2(GN2(G?Z-_:__^%P'A0C7@!2(G#2&/_
MZ'W9__](A<!T/4ACVTB)[DB)QTB)VN@7W/__2(G!Q@08`$B+A"08(```9$@K
M!"4H````=0U(@<0H(```2(G(6UW#Z`O;__\QR>O7#Q^``````.D[____9F8N
M#Q^$``````!!5T%6055!5%5(B?U32('LN!```$B)="0(9$B+!"4H````2(F$
M)*@0``!(BP6OAP``3(LP387V#X0-`@``3(TM4B@``$V)[T$/MD<!28/'`83`
M=`0\/77O28L>32GO2(7;=#]-8_]!O`D```!-.>=-#T;G#Q]$``!,B>),B>Y(
MB=_HBMC__X7`=0M"@#P[/0^$JP$``$F+7@A)@\8(2(7;==:^+P```$B)[^CQ
MV?__2(7`=$1(C3WF)P``,<!(B>[HB_O__TB)Z$B+E"2H$```9$@K%"4H````
M#X5R`0``2('$N!```%M=05Q!74%>05_##Q^``````$R-):\G``!(B>_HR=C_
M_TB+?"0(3(GF08G%Z/G9__])B<9F#Q]$``!-A?9TCT&`/@`/A+D```!(A=MT
M$TR)]DB)W^C!V?__A<`/A(D```!,B??H@=C__^L*#Q^``````,8"`(G!@^@!
M2&/03`'R@#HO=.U"C40I`3W_#P``#X\Y____3(V\)*````!(@^P(38GP54B-
M#1\H``"Z`!```$R)_TR-#0\G``"^`0```#'`Z-/9__](C70D($R)_^@FV/__
M6EF%P'40BT0D*"4`\```/0"```!T0$R)YC'_Z#;9__])B<;I/O___V8/'T0`
M`$B%VW0%@#LN=!9,C36F)@``N0$```#I:/___P\?1```@'L!`'3"Z^*^`0``
M`$R)_^ASV?__A<!UKTB-/7DF``!,B?[H(/K__TR)_^B8V/__Z8O^__\/'P!*
MC5P[`>E8_O__,=OI4?[__^B:V/__9BX/'X0```````^V!TB)^H3`=!=F#Q]$
M``!(@\<!/"](#T37#[8'A,!U[TB)T,-F9BX/'X0``````$B%_P^$OP```%.`
M/P!(B?L/A(H```#H)=?__TB-5`/_2#G3<A3K+V8/'X0``````$B#Z@%(.=-T
M=X`Z+W3R2#G3<@[K$0\?`$B#Z@%(.=-T7X`Z+W7R2#G3=0KK4P\?`(`Z+W4)
M2(/J`4@YTW+R2"G:,<!(C4H"2('Y`!```'<82(/"`;D`$```2(G>2(T]G84`
M`.AHU?__6\-F#Q]$``!;2(T]9R4``.F3U___#Q\`@#LO=.M;2(T]8R4``.E^
MU___9@\?1```2(T]0"4``.ELU___9F8N#Q^$``````"005=(C3U])0``,=)!
M5D%505154TB#[#AF#V\%(6(``&1(BP0E*````$B)1"0H,<!FB50D(`\I!"1F
M#V\%$&(```\I1"00Z/;T__](C3T^)0``,<#HZ/3__TB-/3@E```QP.C:]/__
M2(T],R4``#'`Z,ST__](C3TL)0``,<#HOO3__TB-/2XE```QP.BP]/__2(T]
MCR0``#'`Z*+T__](C3T>)0``,<#HE/3__TB-/1HE```QP.B&]/__2(T]%B4`
M`#'`Z'CT__](C3UB)```,<#H:O3__TB+!9.#``!(BQA(A=L/A*H!``!,C252
M)```38GE00^V10%)@\4!A,!T!#P]=>],BSM-*>5-A?]T0TUC[;T1````28G>
M23GM20]&[0\?@`````!(B>I,B>9,B?_H:M3__X7`=0M#@#PO/0^$TP$``$V+
M?@A)@\8(387_==9,C27Z(P``38GE00^V10%)@\4!A,!T!#P]=>],BS--*>5-
MA?9T0DUC[;T2````28G?23GM20]&[68/'T0``$B)ZDR)YDR)]^@"U/__A<!U
M"T.`/"X]#X2;`0``38MW"$F#QPA-A?9UUDR-+:0C``!!#[9%`4F#Q0&$P'0$
M/#UU[TB+*TB-!8DC``!)*<5(A>UT2DUC[4&\$````$F)WDTYY4F)[TT/1N5F
M#Q]$``!,B>),B?](C358(P``Z([3__^%P'4+0X`\+ST/A*<```!-BWX(28/&
M"$V%_W723(TE0",``$V)Y4$/MD4!28/%`83`=`0\/77O32GE2(7M=$)-8^VX
M$0```$DYQ4D/1L5)B<8/'T0``$R)\DR)YDB)[^@JT___A<!U#$*`?"T`/0^$
M\@```$B+:PA(@\,(2(7M==5(N%!!4E]#3$5!2#E$)!%U-6:!?"093CUU+$B-
M="0;,<!(C3T((P``Z"#V___K%V8/'T0``$N-="\!2(T]4B(``.@']O__2(TU
M#",``#'`2(T]OB(``.CR]?__2(M$)"AD2"L$)2@````/A8P```!(@\0X6UU!
M7$%=05Y!7\,/'X``````2XUT+P%(C3VI(@``Z+?U__](BP5`@0``2(L82(7;
M#X46_O__Z5+___\/'X``````2XUT+@%(C3V-(@``Z(?U__](BP40@0``2(L8
M2(7;#X5._O__Z2+___\/'X``````2HUT+0%(C3T_(@``Z%?U___I2____^CM
MT___9F8N#Q^$``````!FD(L%.H$``(/X_W0%PP\?0`!(BP6Y@```059!54%4
M55-(BRA(A>UT7TR--?4A``!-B?5!#[9%`4F#Q0&$P'0$/#UU[TB+70!-*?5(
MA=MT.$UC[4&\"@```$TYY4T/1N5FD$R)XDR)]DB)W^B2T?__A<!U!T*`/"L]
M="=(BUT(2(/%"$B%VW7:,<!;78D%L(```$%<05U!7L-F#Q^$``````!"#[9$
M*P%;74%</#!!70^5PH3`05X/E<`/ML`AT(D%?8```,-F9BX/'X0``````)!(
M@^P(Z$?3__^)Q^BPT?__2(7`=`-(BP!(@\0(PP\?`$%728G_059!54%43(TE
M5R$``%5-B>932(/L"$B+!;Y_``!(BRA(A>UT7$$/MD8!28/&`83`=`0\/77O
M2(M=`$TIYDB%VW0_36/V0;T0````33GN30]&[F8/'X0``````$R)ZDR)YDB)
MW^BBT/__A<!U!T*`/#,]="](BUT(2(/%"$B%VW7:3(G^3(GG,<!(@\0(6UU!
M7$%=05Y!7^FO\___#Q^``````$J-7#,!@#L`=-1,B?Y(B=_HD]'__TB%P'0/
M2(/$"%M=05Q!74%>05_#3(G_Z/?0__](B=](B<7H[-#__TB-?`4"Z#+0__](
M@^P(O@$```!-B?A(B<=(B<532,?"_____TR-#9\?```QP$B-#9D@``#H8]+_
M_TB)[DR)YS'`2(/$&.ED____9I!(@^P(OX````#HXL___V8/;P6*7```2,=`
M,``````/$0!F#V\%AUP``,=`>``````/$4`09@]O!81<```/$4`@2(/$",-F
M9BX/'X0``````$%7059!54%455-(B?M(@^P8Z/KX__\/MA!)B<:$TG022(/`
M`8#Z+TP/1/`/MA"$TG7NBP68?@``2(7;#Y5$)`</MDPD!X/X_W1>A<!`#Y7%
M(<U`A.UU&4B#Q!A;74%<05U!7D%?PV8N#Q^$``````"`.P!TXDB--7T?``"Z
M!````$R)]^@'S___A<!URDB#Q!A(B=];74%<05U!7D%?Z7WO__\/'T0``$B+
M!;%]``!,BSA-A?\/A*0```!,C2WQ'@``00^V10%)@\4!A,!`#Y7%/#T/E<!`
M(,5UYTV+)TB-!<X>``!)*<5-A>1T<DUC[;@*````23G%20]&Q4B)1"0(#Q^`
M`````$B+5"0(2(TUGQX``$R)Y^ATSO__A<!U!T.`/"P]=!I-BV<(28/'"$V%
MY'74,<")!91]``#I$?___T,/MD0L`83`0`^5Q3PP#Y7`(<5`#[;%0")L)`?K
MU\<%9WT```````#IZ?[__V:005=(8\)!5DF)QD%5051)B?Q52(UO.%-(B?-(
M@^P(2(MW*$B+3S"-%,9(.?)F2`]NPDB#T0!(P>@=2`'(9D@/;NA(8T=X9@]L
MQ0\11RB%P`^%PP```$&#_C\/C@$!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=
M#Q\`\P]O"TR)YTB#PT`/$4T`\P]O4]`/$540\P]O6^`/$5T@\P]O8_`/$64P
MZ'G3__],.>MUS$'!YP9%*?Y)8\9(@_@(<C1)BU0%^$B-2/](B>],B>Y(P>D#
M2(E4!?CS2*5%B70D>$B#Q`A;74%<05U!7D%?PP\?1```J`1U=$B%P'3>00^V
M50!!B%0D.*@"=-!!#[=4!?YFB50%_NO##Q]``$B-?`4`0;]`````2(G>02G'
M13GW10]/_DUC[TR)ZNBES___08M$)'A$`?A!B40D>(/X0'6/3(GG12G^3`'K
MZ,72___I]?[__TF)W>E+____08M5`$&)5"0X08M4!?R)5`7\Z5C___^0059,
MC78X055!5%5(B?U33(MN*$B)\TR+9C!,B>A(P>@#@^`_C4@!2)A(8]'&1`8X
M@$P!\H/Y.`^.@P$``+Y`````*<YT#S'`B<&#P`'&!`H`.?!R\TB)W^A#TO__
M9@_OP`\10SA!#Q%&$$$/$48@2<=&,`````!,B>)!#[;%3(GO2,'J&$C!X`A,
MB>Y)B=!,B>I(P>\0#[;60`^V_TC![AA("=!`#[;V3(GB2,'@"$R)X4@)^`^V
M_DC!Z1!(P>`(#[;)00^VT$@)\$$/MO1(P>`(2`GP2,'@"$@)^$B)WTC!X`A(
M"<A(P>`(2`G02(E#<.BJT?__2(L#2(G?2,'H&(A%`$B+`TC!Z!"(10%(BP.(
M90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#"(AE!DB+0PB(10=(
MBT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(10M(BT,82,'H&(A%
M#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H&(A%$$B+0R!(P>@0
MB$412(M#((AE$DB+0R"(11-;74%<05U!7NF:R___9BX/'X0``````+@X````
M*<B#^`AS)*@$=4B%P`^$G_[__\8"`*@"#X24_O__,<EFB4P"_NF(_O__D(G!
M2(G72,=$"O@`````C4C_B<C!Z`.)P3'`\TBKZ67^__]F#Q]$``#'`@````#'
M1`+\`````.E,_O__#Q]$``!!5TB-#><:``!!5F9(#V[!055(C0T5&@``0515
M4TB![%B!``!,BR45>0``2(E\)!!D2(L$)2@```!(B80D2($``$B-!;<9``!(
MQT0D4`````!(QX0DB`````````!(QT0D,`````!-BSPD9D@/;LA(C05_&@``
M9@]LP0\I1"1`9D@/;L%(C0VU&0``9D@/;M!(C05F&@``9@]LP@\11"1H9D@/
M;L%F2`]NV$B-!5`:``!F#VS##Q%$)'A(B40D*$V%_W1F3(TM*QD``$V)[D$/
MMD8!28/&`83`=`0\/77O28L?32GN2(7;=$!-8_:]"0```$DY[DD/1NX/'X``
M````2(GJ3(GN2(G?Z&+)__^%P'4+0H`\,ST/A#H#``!)BU\(28/'"$B%VW76
MZ&'+__^)Q^C*R?__2(7`#X1E`P``2(LH2(7M#X19`P``2(GOZ-W)__](C7P`
M`>@CR?__1`^V10!)B<5(B40D"$6$P'1`2(T=E!D``&8N#Q^$``````!%#[;`
M3(GO2(G92,?"_____[X!````,<#H0\O__T0/MD4!2(/%`4F#Q0)%A,!UT4V+
M-"1(C80DD````$R-;"1@2(D$)$B-+>88``!-A?9T>`^V10`\/0^$=`(``(3`
M#X1L`@``2(GK#[9#`4B#PP&$P'0$/#UU\"GK38L^387_=#%(8]L/'T``2(G:
M2(GN3(G_Z%K(__^%P'4+08`\'ST/A+L!``!-BWX(28/&"$V%_W7628MM"$B%
M[70-38LT)$F#Q0A-A?9UB$B-;"1`3(VL))````#K%&8/'X0``````#T`H```
M=#A(@\4(2(M=`$B%VW10@#L`#X0@`@``3(GN2(G?Z/C)__^%P'7;BX0DJ```
M`"4`\```/0!```!UP;X"````2(G?Z$3*__^%P'6W2(G?2(/%".ATR?__2(G#
M2(7`=*=(B=_H9,C__TR+="0(2(G%3(GWZ%3(__^-K`4$!```2&/M2(GOZ)+'
M__](C0WD%P``28G82,?"_____TB)!"1(B<>^`0```$B)PT%63(T-^18``#'`
M44B-#>X7``#HNLG__TB)W[[``0``Z!W*__]?05B#^/]U$NC@R/__1(L(08/Y
M$0^%,P0``$B+/"1(C80DD````$B)QDB)1"08Z!K)__^)PX7`=1>+A"2H````
M)0#P```]`$````^$]`$``$R+!"1(C14J&```O@$```!(BT0D$$B+"$B+!>9U
M``!(BS@QP.B$QO__,>U(BX0D2($``&1(*P0E*`````^%T@8``$B!Q%B!``!(
MB>A;74%<05U!7D%?PV8/'T0``$F-7!\!@#L`#X1$_O__2(LT)$B)W^B&R/__
MA<`/A3#^__^+A"2H````)0#P```]`$```'0+/0"@```/A1+^__^^`@```$B)
MW^C#R/__A<`/A?W]__](B=_H\\?__TB)PTB%P`^%>_[__^GZ_?__9I`QV^FB
M_?__2HU<,P&`.P`/A,7\__](B=_H\_3__TB+A"1(@0``9$@K!"4H````#X43
M!@``2('$6($``$B)WUM=05Q!74%>05_ID\?__S';Z2#^__],C70D($R-+306
M``!-BSPD387_=%Q!#[9%`(3`#X2J````/#T/A*(```!,B>T/MD4!2(/%`83`
M=`0\/77P1"GM28L?2&/M2(7;=":02(GJ3(GN2(G?Z'+%__^%P'4&@#PK/71(
M28M?"$F#QPA(A=MUVTV+;@A)@\8(387M=8Y(C2W`%0``OPT```#H3<7__T&X
M4P```$F)Q4B)1"0(Z2G\__]F+@\?A```````2(U\*P&`/P!TN^C1QO__2(G%
M2(7`#X7@^___ZZ@/'P`Q[>EM____1(NT)*P```#H#,?__T$YQ@^%]OW__XN$
M)*@````E_P$``#W``0``#X7?_?__3(T]*14``$B)[^C-Q/__38LL)$B)Q4V%
M[71Q00^V1P%)@\<!A,!T!#P]=>]-BW4`2(T%^10``$DIQTV%]G1-36/_N`4`
M``!).<=)#T;'2(E$)`AF#Q^$``````!(BU0D"$B--<@4``!,B??H7,3__X7`
M=0M#@#P^/0^$BP$``$V+=0A)@\4(387V==!(BT0D$$R+,$R)]^CPQ/__28G'
M@_@#?C)(C37)%```2)A)C7P&_.@%QO__A<!U&T&#_P0/A&\#``!!C4?[2)A!
M@#P&+P^$7@,``(L%,',``(/X_P^$4`$``(7`=1<Q]DR)]S'`Z`?%__]!B<2%
MP`^%RP$``$B--1$4```QP$B-/=\3``#H]^;__TR-)984``#H*\3__T%42,?"
M_____[X!````4$R+1"002(GO,<!,C0TK$P``2(T-110``$R-/1T3``#HZ,7_
M_TR--4`4``!86NM$#Q]$``#H$\7__X,X$75'Z-G#__^#PP%(@^P(38GY051,
MB?%(Q\+_____2(GO4[X!````4$R+1"0@,<#HG<7__TB#Q""^P`$``$B)[^C\
MQ?__@_C_=*](BSPDZ+[#__](B>XQP$B-/8@2``#H/>;__TB)[^CE\?__Z2[\
M__],BP0D2(T5[1,``+X!````2(M$)!!(BPA(BP7I<0``2(LX,<#HA\+__^G^
M^___2XU\/@'H>,3__TB)QDB+1"002(LXZ)CI__])B<9(A<`/A63^___I5_[_
M_TV+)"1-A>0/A*("``!,C2VF$@``3(GH#[90`4B#P`&$TG0%@/H]=>]-BSPD
M3"GH387_#X1W`@``2&/(N`H```!(.<%(B4PD$$@/1L%(B40D"&8/'T0``$B+
M5"0(3(GN3(G_Z##"__^%P'402(M$)!!!@#P'/0^$:@$``$V+?"0(28/$"$V%
M_W7.,<")!49Q``#I&O[__[H"````2,?&[O___XG'Z#[$__],C;0D0`$``+H&
M````1(GG3(GVZ,;!__^`O"1``0```'4.@+PD00$``$,/A&8!```QTC'V1(GG
MZ`+$__^_@````.BXP?__9@]O!6!.``!(B<-(QT`P``````\1`&8/;P5:3@``
MQT!X``````\10!!F#V\%5TX```\10"#K"TR)]DB)W^A&\___N@"```!,B?9$
MB>?H1L'__XG"A<!_WTR-O"0@`0``1(GGZ-#`__](B=Y,B?_HE?3__TR+9"08
M3(VT)+@```!(C1V[$0``D$4/M@=,B>=(B=F^`0```$C'PO____\QP$F#Q`))
M@\<!Z&O#__]-.>9UUDB-!=41``#&A"2X`````%#_="0@3(M$)!"^`0```$B)
M[S'`2(T-?A$``$C'PO____],C0U>$```Z"G#__]97NF;_?__00^V1`<!/#`/
ME<*$P`^5P`^VP"'0Z8S^__](BT0D$$R+>`A-A?\/A)#\__],B?_H/L'__TB#
M^`,/AG[\__])C7P'_$B--141``#H4\+__X7`30]$]^EB_/__@+PD0@$``$$/
MA8S^__^`O"1#`0``0P^%?O[__X"\)$0!``!(#X5P_O__@+PD10$``$4/A6+^
M__^Z`@```$C'QL;___]$B>?H7,+__[HI````3(GV1(GGZ.R___](C07;$```
M4$%6Z0O___\/'T0``,<%'F\```````#I]OO__^BTP?__#Q]``$%7059!54%4
M55-(@^P(9$B+!"4`````2`,%LFX``$R+,$$/MH:P````08B&L0```$B+!6EN
M``!,BSA-A?]T8TR-+9$/``!-B>Q!#[9$)`%)@\0!A,!T!#P]=>Y)BQ]-*>Q(
MA=MT/$UCY+T0````23GL20]&[`\?`$B)ZDR)[DB)W^A*O___A<!U"T*`/",]
M#X13`P``28M?"$F#QPA(A=MUUC'`Z(?I__]D2(L$)0````!(`P47;@``3(LP
MN0L```"Z`0```$R)]TB-->`/``#H.[___TB%P`^$TP```$B+0!"#/6]N```!
M3(MH*`^.O@```#';ZU1F#Q^$```````E`$$@`#T`00``#X2&````28L_N0(`
M```QTNBAP?__2(G&2(L%-VX``$ECU$B+/-#HB\#__XG"BP4;;@``A=)U98/%
M`D2)XSG%?5MD2(L$)0````!(`P5U;0``3&/S,<E,B>Y$C6,!3(GRB=U(BSA)
MB<?HR;___TB%P'0D2(LPBT8,B<*!X@`$(`"!^@`$```/A6K___](BW80ZX8/
M'T``BP6R;0``C5#_.=H/A%<"``!D2(L$)0````!(`P4/;0``N0,```"Z`0``
M`$B-->,.``!(BSA(B<7H,[[__TB)PTB%P'0H2(M`$$B-%<<.``!(BWT`2(LP
MZ$2^__](BT,02(LP]D8.0`^%A`(``&1(BP0E`````$@#!;-L``"Y`P```+H!
M````2(TUIPX``$B+..C:O?__28G&2(7`#X2.````2(L%5VP``$R+.$V%_W1I
M3(TM"0T``$V)[$$/MD0D`4F#Q`&$P'0$/#UU[DF+'TTI[$B%VW1"36/DO0T`
M``!).>Q)#T;L9@\?A```````2(GJ3(GN2(G?Z#*]__^%P'4+0H`\(ST/A*,!
M``!)BU\(28/'"$B%VW762(L%GVP``$B+,$F+1A!(BSCH8-___V1(BP0E````
M`$@#!?!K``"Z`0```$B--=`-``!,C2UC#```38GN2(LX2(G#Z#^\__](BSM(
MC17&#0``2(G&Z"V]__](BP/&@+$`````2(L%?&L``$B+*$B%[71>00^V1@%)
M@\8!A,!T!#P]=>](BUT`32GN2(7;=$%-8_9!O`D```!-.>9-#T;F#Q^`````
M`$R)XDR)[DB)W^ABO/__A<!U"T*`/#,]#X0#`0``2(M="$B#Q0A(A=MUUDB+
M/<]K``!(QP6T:P```````.B_\?__2(G#2(D%I6L``$B%P`^$ZP```+[``0``
M2(G?Z.^^__^-4`&#^@%V"8/X$0^%VP```$B#Q`A;74%<05U!7D%?PP\?@```
M``!*C40C`8`X,0^%K/S__X!X`0`/A+S\___IG?S__P\?`(/X`0^.H/W__[L!
M````9BX/'X0``````&1(BP0E`````$@#!:!J``!,B>Z#PP%(BSCHPKO__SD=
M%&L``'_:Z6;]__\/'T0``$F+1A!*C6PC`4B+&&1(BP0E`````$@#!61J``!(
MB>I(B=Y(BSCHQKO__^E1_O__D$J-7#,!2(D=Q&H``.DC____2(M]`.@&O?__
MZ6[]__](C3W*#```,<#H4[W__TB-/>0,``")P4B+!:-J``!(B=I(BS`QP.@V
MO?__9@\?1```2(L-,6H``.G4NO__2(/L"$B#Q`C#````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`4$%27U1%35``+@!005)?4%)/1TY!344`.@`O`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]435!$25(`,0!005)?0TQ%04X]`$Q$7TQ)0E)!4EE?
M4$%42`!P87(M`"UE`"TM`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``
M55-%4DY!344`)3`R>``E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4P```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`]
M(")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*
M)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H
M=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E
M;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O<RP@
M,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?
M<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B
M=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H
M56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@
M)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N
M86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D
M92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO
M9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A
M;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B
M4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G
M:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M
M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD
M+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2![
M"FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*
M:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I
M;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=
M*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*
M96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM
M>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H
M4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@
M)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN
M;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,
M12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C
M;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH
M;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#
M*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(
M86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@
M<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*
M?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D
M9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D
M;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG
M97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@
M)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP
M;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*
M8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I+F,`
M``````````````````#_____`````/____\`````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`!(T5G`````(FKS>\`````_MRZF`````!V5#(0
M`````/#ATL,````````````````!&P,[[````!P```!@<O__.`$``!!V__]@
M`0``(';__^0%```@>/__"`$``!!Y__]X`0``X)'__\@!``"PDO__%`(``*"3
M__]@`@``$)7__YP"``!PE?__N`(``%"6___T`@``\)C__U@#```PF?__<`,`
M`/"9__^<`P```)K__[`#``!@G/__$`0``)"<__\D!```<)W__TP$```0H?__
MF`0``."A___D!````*+___P$```PH___:`4``("C__^`!0``\*3__Q`&``!P
MIO__7`8``*"H__^<!@``0+/__VP'```0N/__N`<````````4``````````%Z
M4@`!>!`!&PP'")`!!Q`4````'````!!W__\B```````````````4````````
M``%Z4@`!>!`!&PP'")`!```D````'````"!Q__^P`P````X01@X82@\+=PB`
M`#\:.RHS)"(`````%````$0```"H=/__"```````````````3````%P```"0
M=___R1@```!"#A"/`D4.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`Z48
M"@XX00XP00XH0@X@0@X80@X00@X(00L```!(````K````!"0___,`````$(.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@
M0@X80@X00@X(20L`2````/@```"4D/__[0````!"#A"/`D(.&(X#0@X@C01"
M#BB,!4$.,(8&1`XX@P=$#D`">@H..$$.,$$.*$(.($(.&$(.$$(."$L+`#@`
M``!$`0``.)'__VP!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.
M($$.&$(.$$(."$<+`!@```"``0``;)+__U4`````00X0@P)^#@@````X````
MG`$``+"2___@`````$(.$(T"1PX8C`-!#B"&!$0.*(,%40[`(`)L"@XH00X@
M00X80@X00@X(1PM@````V`$``%23__^>`@```$(.$(\"0@X8C@-"#B"-!$(.
M*(P%1`XPA@9$#CB#!T0.4`/Q`0H..$$.,$$.*$(.($(.&$(.$$(."$$+7`H.
M.$$.,$$.*$(.($(.&$(.$$(."$H+%````#P"``"0E?__-0````!$#A!L#@@`
M*````%0"``"XE?__N0````!!#A"&`D$.&(,#1P[`0`*A"@X81`X000X(00L0
M````@`(``$R6__\%`````````%P```"4`@``2);__U8"````0@X0CP)"#AB.
M`T(.((T$0@XHC`5!#C"&!D0..(,'1P[P(0+2"@XX00XP00XH0@X@0@X80@X0
M0@X(2`L"CP[X(40.@")P#O@A00[P(0```!````#T`@``2)C__R4`````````
M)`````@#``!DF/__U`````!*#A"#`@*/"@X(1PM!"L,."$\+1L,."$@````P
M`P``')G__Y,#````0@X0CP)+#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`YP
M`^\""@XX00XP00XH0@X@0@X80@X00@X(2`M(````?`,``'"<___$`````%D.
M$(X"0@X8C0-"#B",!$$.*(8%00XP@P8":@H.*$$.($@.&$(.$$(."$H+1PXH
M00X@0@X81`X01PX(%````,@#``#TG/__'0````!$#A!8#@@`:````.`#``#\
MG/__+@$```!"#A"/`D4.&(X#0@X@C01"#BB,!4@.,(8&1`XX@P=$#D`"=PXX
M00XP00XH0@X@0@X80@X00@X(3`Y`7@H..$$.,$$.*$(.($(.&$(.$$(."$$+
M80Y(3PY0:`XX%````$P$``#`G?__10````!$#A`"0`X(8````&0$``#XG?__
M;@$```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#E`"2@H..$$.
M,$$.*$(.($(.&$(.$$(."$L+80H..$0.,$$.*$(.($(.&$(.$$(."$H+`"@`
M``#(!```-'#___P!````00X0A@)!#AB#`T0.4`.?`0H.&$,.$$$."$$+2```
M`/0$``#8GO__?P$```!"#A"/`D4.&(X#10X@C01"#BB,!40.,(8&10XX@P='
M#D`"P@H..$$.,$$.*$(.($(.&$(.$$(."$8+`#P```!`!0``#*#__RL"````
M0@X0C@)&#AB-`T(.((P$00XHA@5$#C"#!@.;`0H.*$$.($(.&$(.$$(."$\+
M``#,````@`4``/RA__^<"@```$(.$(\"20X8C@-'#B"-!$D.*(P%00XPA@9!
M#CB#!T<.D(,"`^P"#IB#`DH.H(,"6@Z8@P)"#I"#`@*6"@XX1`XP00XH0@X@
M0@X80@X00@X(1PL"JPH..$0.,$$.*$(.($(.&$(.$$(."$4+`RH"#IB#`DT.
MH(,";`Z8@P)!#I"#`ET.F(,"10Z@@P).#JB#`D8.L(,"4`Z0@P(#0P(.F(,"
M1`Z@@P)J#IB#`D$.D(,"`L,*#IB#`D(.H(,"2@L`2````%`&``#,J___R@0`
M``!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`#R`,*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A("Q````"<!@``4+#__PP`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````,`F````````@"8````````!````````
M`!8#`````````0`````````A`P````````$`````````*P,````````/````
M`````,$$````````#```````````(`````````T`````````W&4````````9
M`````````'C+````````&P`````````(`````````!H`````````@,L`````
M```<``````````@`````````!`````````#``P```````/7^_V\`````2`@`
M```````%`````````*@2````````!@````````"0"0````````H`````````
MWP0````````+`````````!@`````````%0````````````````````,`````
M````N,T````````"`````````'`%````````%``````````'`````````!<`
M````````<!H````````'`````````/`8````````"`````````"``0``````
M``D`````````&``````````8````````````````````^___;P`````!```(
M`````/[__V\`````4!@```````#___]O``````(`````````\/__;P````"(
M%P```````/G__V\`````!```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(C+`````````````````````````````#8@````````
M1B````````!6(````````&8@````````=B````````"&(````````)8@````
M````IB````````"V(````````,8@````````UB````````#F(````````/8@
M````````!B$````````6(0```````"8A````````-B$```````!&(0``````
M`%8A````````9B$```````!V(0```````(8A````````EB$```````"F(0``
M`````+8A````````QB$```````#6(0```````.8A````````]B$````````&
M(@```````!8B````````)B(````````V(@```````$8B````````5B(`````
M``!F(@```````'8B````````AB(```````"6(@```````*8B````````MB(`
M``````#&(@```````-8B````````YB(```````#V(@````````8C````````
M%B,````````F(P```````#8C````````1B,```````!6(P```````&8C````
M````=B,```````"&(P```````)8C````````IB,```````"V(P```````,8C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````X'(```````!'
M0T,Z("A'3E4I(#$R+C(N,"`R,#(R,#@Q.2`H04]30R!/4RP@0V]R92D``"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N
M8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@`````````8`P```````!@#````````'```````
M``````````````$````````````````````3````!P````(`````````.`,`
M```````X`P```````$`````````````````````(````````````````````
M)@````<````"`````````'@#````````>`,````````D````````````````
M````!````````````````````#D````'`````@````````"<`P```````)P#
M````````(`````````````````````0```````````````````!+````!0``
M``(`````````P`,```````#``P```````(0$````````!P`````````(````
M``````0`````````1P```/;__V\"`````````$@(````````2`@```````!$
M`0````````<`````````"````````````````````%$````+`````@``````
M``"0"0```````)`)````````&`D````````(`````0````@`````````&```
M``````!9`````P````(`````````J!(```````"H$@```````-\$````````
M```````````!````````````````````80```/___V\"`````````(@7````
M````B!<```````#"``````````<``````````@`````````"`````````&X`
M``#^__]O`@````````!0&````````%`8````````H``````````(`````@``
M``@```````````````````!]````!`````(`````````\!@```````#P&```
M`````(`!````````!P`````````(`````````!@`````````AP````0```!"
M`````````'`:````````<!H```````!P!0````````<````8````"```````
M```8`````````)$````!````!@``````````(``````````@````````%P``
M``````````````````0```````````````````",`````0````8`````````
M("`````````@(````````+`#```````````````````0`````````!``````
M````EP````$````&`````````-`C````````T",````````(````````````
M````````"``````````(`````````*`````!````!@````````#@(P``````
M`.`C````````_$$``````````````````!````````````````````"F````
M`0````8`````````W&4```````#<90````````D````````````````````$
M````````````````````K`````$````"``````````!P`````````'``````
M``#`/0``````````````````$````````````````````+0````!`````@``
M``````#`K0```````,"M````````[`````````````````````0`````````
M``````````#"`````0````(`````````L*X```````"PK@```````.`&````
M```````````````(````````````````````S`````X````#`````````'C+
M````````>+L````````(````````````````````"``````````(````````
M`-@````/`````P````````"`RP```````("[````````"```````````````
M``````@`````````"`````````#D````!@````,`````````B,L```````"(
MNP```````#`"````````"``````````(`````````!``````````FP````$`
M```#`````````+C-````````N+T```````!(`@``````````````````"```
M```````(`````````.T````!`````P``````````T`````````#`````````
M(`````````````````````@```````````````````#S````"`````,`````
M````(-`````````@P````````&`0```````````````````@````````````
M````````^`````$````P````````````````````(,`````````K````````
M`````````````0`````````!``````````$````#````````````````````
L`````$O``````````0$```````````````````$`````````````````````
